# coding=utf-8
# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2025 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

import subprocess
import logging
from clcommon.public_hooks.lib import ModifyDomainHook, ModifyUserHook

from wmt.common.const import SYSTEMCTL_BIN

class WmtDomainHook(ModifyDomainHook, ModifyUserHook):
    """
    This hook is used to modify the wmt database when a domain is deleted.
    """

    @staticmethod
    def _is_service_active() -> bool:
        """Checks if a cl_wmt_scanner.service is active."""
        try:
            process = subprocess.run(
                [SYSTEMCTL_BIN, 'is-active', '--quiet', 'cl_wmt_scanner.service'],
                check=True,
                capture_output=True
            )
            return True
        except subprocess.CalledProcessError:
            # A non-zero exit code means the service is not active (e.g., inactive, failed)
            return False
        except FileNotFoundError as e:
            logging.error(f"Systemctl command not found: {e}")
            return False

    def _reload_scanner_service(self):
        """
        Reloads the scanner service using systemctl. 
        We need to get a new list of domains after update/delete of domains
        """
        if self._is_service_active():
            try:
                command = [SYSTEMCTL_BIN, 'restart', 'cl_wmt_scanner.service']
                result = subprocess.run(command, check=True, capture_output=True, text=True)
            except subprocess.CalledProcessError as e:
                logging.error(f"Failed to reload scanner service: {e}\nStdout: {e.stdout}\nStderr: {e.stderr}")
            except FileNotFoundError as e:
                logging.error(f"Systemctl command not found: {e}")
            except Exception as e:
                logging.exception("An unexpected error occurred while reloading scanner service.")

    def post_modify_domain(self, username, domain, new_domain=None, include_subdomains=None, **kwargs):
        """Hook to be called after domain modification."""
        if new_domain and domain != new_domain:
            # Reload service after successful update
            self._reload_scanner_service()